@@ -1,4 +1,5 @@
 from os import system as cmd
+import os
 from time import sleep as wait
 try:
     from selenium import webdriver
@@ -9,6 +10,9 @@ try:
     from selenium.webdriver.common.by import By
     from selenium.common.exceptions import TimeoutException
     from selenium.webdriver.chrome.options import Options
+    from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
+    from selenium.webdriver.firefox.firefox_binary import FirefoxBinary
+    from selenium.webdriver.firefox.options import Options
 
 except ModuleNotFoundError:
     cmd('pip3 install selenium')
@@ -20,16 +24,28 @@ except ModuleNotFoundError:
     from selenium.webdriver.common.by import By
     from selenium.common.exceptions import TimeoutException
     from selenium.webdriver.chrome.options import Options
+    from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
+    from selenium.webdriver.firefox.options import Options
+    from selenium.webdriver.firefox.firefox_binary import FirefoxBinary
 
 
 class WhatsappAPI():
 
     @classmethod
-    def setup(self):
-        options = webdriver.ChromeOptions()
-        options.add_argument('--user-data-dir=C:/Users/enzon/AppData/Local/Google/Chrome/User Data/Default')
-        self.driver = webdriver.Chrome(options=options)
-        self.driver.get('https://web.whatsapp.com')
+    def setup(self, browser):
+        userprof = os.environ['USERPROFILE']
+
+        if browser.lower() == 'firefox':
+            profile = webdriver.FirefoxProfile(f'{userprof}/AppData/Roaming/Mozilla/Firefox/Profiles/931td2o2.default-release')
+            print(userprof)
+            self.driver = webdriver.Firefox(firefox_profile=profile)
+            self.driver.get('https://web.whatsapp.com')
+
+        if browser.lower() == 'chrome':
+            options = webdriver.ChromeOptions()
+            options.add_argument(f'--user-data-dir={userprof}/AppData/Local/Google/Chrome/User Data/Default')
+            self.driver = webdriver.Chrome(options=options)
+            self.driver.get('https://web.whatsapp.com')
 
     @classmethod
     def find_contact(self, contact):
